@@ -34,6 +34,9 @@
 #' @param max_walk_dist numeric. Maximum walking distance (in meters) for the
 #'                      whole trip. Defaults to no restrictions on walking, as
 #'                      long as \code{max_trip_duration} is respected.
+#' @param max_bike_dist numeric. Maximum cycling distance (in meters) for the
+#'                      whole trip. Defaults to no restrictions on cycling, as
+#'                      long as \code{max_trip_duration} is respected.
 #' @param max_trip_duration numeric. Maximum trip duration in minutes. Defaults
 #'                          to 120 minutes (2 hours).
 #' @param walk_speed numeric. Average walk speed in km/h. Defaults to 3.6 km/h.
@@ -47,8 +50,10 @@
 #'                 See details for more information.
 #' @param n_threads numeric. The number of threads to use in parallel computing.
 #'                  Defaults to use all available threads (Inf).
-#' @param verbose logical. TRUE to show detailed output messages (the default)
-#'                or FALSE to show only eventual ERROR messages.
+#' @param verbose logical. `TRUE` to show detailed output messages (the default).
+#'                If verbose is set to `FALSE`, r5r prints a progress counter and
+#'                eventual `ERROR` messages. Setting `verbose` to  `FALSE` imposes
+#'                a small penalty for computation efficiency.
 #'
 #' @return A data.table with travel time estimates (in minutes) between origin
 #' destination pairs by a given transport mode. Note that origins/destinations
@@ -56,7 +61,7 @@
 #' the street network are not returned in the data.table.
 #'
 #' @details
-#'  # Transpor modes:
+#'  # Transport modes:
 #'  R5 allows for multiple combinations of transport modes. The options include:
 #'
 #'   ## Transit modes
@@ -138,6 +143,7 @@ travel_time_matrix <- function(r5r_core,
                                time_window = 1L,
                                percentiles = 50L,
                                max_walk_dist = Inf,
+                               max_bike_dist = Inf,
                                max_trip_duration = 120L,
                                walk_speed = 3.6,
                                bike_speed = 12,
@@ -175,10 +181,13 @@ travel_time_matrix <- function(r5r_core,
   checkmate::assert_numeric(max_trip_duration)
   max_trip_duration <- as.integer(max_trip_duration)
 
-  # max_walking_distance and max_street_time
-  max_street_time <- set_max_street_time(max_walk_dist,
-                                         walk_speed,
-                                         max_trip_duration)
+  # max_walking_distance, max_bike_distance, and max_street_time
+  max_walk_time <- set_max_street_time(max_walk_dist,
+                                       walk_speed,
+                                       max_trip_duration)
+  max_bike_time <- set_max_street_time(max_bike_dist,
+                                       bike_speed,
+                                       max_trip_duration)
 
   # origins and destinations
   origins      <- assert_points_input(origins, "origins")
@@ -224,20 +233,21 @@ travel_time_matrix <- function(r5r_core,
 
   # call r5r_core method ----------------------------------------------------
 
-  travel_times <- r5r_core$travelTimeMatrixParallel(origins$id,
-                                                    origins$lat,
-                                                    origins$lon,
-                                                    destinations$id,
-                                                    destinations$lat,
-                                                    destinations$lon,
-                                                    mode_list$direct_modes,
-                                                    mode_list$transit_mode,
-                                                    mode_list$access_mode,
-                                                    mode_list$egress_mode,
-                                                    departure$date,
-                                                    departure$time,
-                                                    max_street_time,
-                                                    max_trip_duration)
+  travel_times <- r5r_core$travelTimeMatrix(origins$id,
+                                            origins$lat,
+                                            origins$lon,
+                                            destinations$id,
+                                            destinations$lat,
+                                            destinations$lon,
+                                            mode_list$direct_modes,
+                                            mode_list$transit_mode,
+                                            mode_list$access_mode,
+                                            mode_list$egress_mode,
+                                            departure$date,
+                                            departure$time,
+                                            max_walk_time,
+                                            max_bike_time,
+                                            max_trip_duration)
 
 
   # process results ---------------------------------------------------------
