@@ -197,7 +197,48 @@ assert_points_input <- function(df, name) {
 
 }
 
+#' Assert decay function and parameter values
+#'
+#' @param decay_function Name of decay function.
+#' @param decay_value Value of decay parameter.
+#'
+#' @return A `list` with the validated decay function and parameter value.
+#' @family support functions
 
+assert_decay_function <- function(decay_function, decay_value) {
+  # list of all decay functions
+  decay_functions  <- c('STEP','EXPONENTIAL','FIXED_EXPONENTIAL','LINEAR','LOGISTIC')
+
+  # check if decay_function is valid
+  checkmate::assert_character(decay_function)
+  decay_function <- toupper(decay_function)
+
+  if (!decay_function %chin% decay_functions) {
+    stop(paste0(decay_function, " is not a valid 'decay function'.\nPlease use one of the following: ",
+                paste(unique(decay_functions), collapse = ", ")))
+  }
+
+  # check if decay_value is numeric and within correct bounds
+  checkmate::assert_numeric(decay_value)
+  decay_value <- as.double(decay_value)
+
+  if (decay_function %chin% c("FIXED_EXPONENTIAL")) {
+    if (decay_value <= 0 | decay_value >= 1) {
+      stop(paste0(decay_value, " is not a valid decay_value parameter for the FIXED EXPONENTIAL decay function.\n",
+                  "Please enter a value between 0 and 1 (exclusive)."))
+    }
+  }
+
+  if (decay_function %chin% c("LOGISTIC", "LINEAR")) {
+    if (decay_value < 1) {
+      stop(paste0(decay_value, " is not a valid decay_value parameter for the ", decay_function, " decay function.\n",
+                  "Please enter a value greater than or equal to 1."))
+    }
+  }
+
+  decay_list <- list("fun" = decay_function, "value" = decay_value)
+  return(decay_list)
+}
 
 #' Set number of threads
 #'
@@ -354,11 +395,16 @@ download_metadata <- function(){
   # Download medata
     # test server connection
     metadata_link <- 'https://www.ipea.gov.br/geobr/r5r/metadata.csv'
-    check_connection(metadata_link)
+    if (check_connection(metadata_link)) {
+      # download it and save it to JAR folder
+      utils::download.file(url=metadata_link, destfile=metadata_file,
+                           overwrite=TRUE, quiet=TRUE)
+    } else {
+      message("Using cached metadata file.")
+
+      metadata_file <- file.path(.libPaths()[1], "r5r", "extdata", "metadata_r5r.csv")
+    }
 
-    # download it and save it to JAR folder
-    utils::download.file(url=metadata_link, destfile=metadata_file,
-                         overwrite=TRUE, quiet=TRUE)
   }
 
   # read metadata
@@ -385,13 +431,15 @@ check_connection <- function(file_url = 'https://www.ipea.gov.br/geobr/metadata/
   # check internet connection
   if (!curl::has_internet()) {
     message("No internet connection.")
-    return(invisible(NULL))
+    return(FALSE)
   }
 
   # test server connection
   # crul::ok(file_url)
   if (httr::http_error(httr::GET(file_url))) {
-    message("Problem connecting to data server. Please try geobr again in a few minutes.")
-    return(invisible(NULL))
+    message("Problem connecting to data server.")
+    return(FALSE)
   }
+
+  return(TRUE)
 }
