@@ -29,7 +29,9 @@ NULL
 if(getRversion() >= "2.15.1") utils::globalVariables(
   c('is', 'duration', 'fromId', 'toId', 'option', 'option', '.SD', 'geometry',
     'route', 'temp_duration', 'temp_route', 'route', 'temp_sign', '.I',
-    'segment_duration', 'total_duration', 'wait', 'release_date', 'con'))
+    'segment_duration', 'total_duration', 'wait', 'release_date', 'con',
+    "start_lon", "start_lat", "end_lon", "end_lat", "slope",
+    "walk_multiplier", "bike_multiplier", "found"))
 
 
 
