@@ -5,13 +5,13 @@ testthat::skip_on_cran()
 
 # setup_r5
 path <- system.file("extdata/poa", package = "r5r")
-r5_core <- setup_r5(data_path = path, verbose=FALSE)
+r5r_core <- setup_r5(data_path = path, verbose=FALSE)
 
 
 # expected behavior
 test_that("street_network_to_sf - expected behavior", {
 
-  testthat::expect_type( street_network_to_sf(r5_core), 'list')
+  testthat::expect_type( street_network_to_sf(r5r_core), 'list')
 })
 
 
@@ -23,3 +23,4 @@ test_that("street_network_to_sf - expected errors", {
   testthat::expect_error( street_network_to_sf('a') )
   })
 
+stop_r5(r5r_core)
